acceptance_coverage

Function acceptance_coverage 

fn acceptance_coverage<'hir>(
    gcx: Gcx<'hir>,
    hir: &'hir Hir<'hir>,
    cond: &'hir Expr<'hir>,
    recipient: VariableId,
    token: VariableId,
) -> GuardCoverage
The condition of a require/assert that passes only if the recipient can receive the token: the recipient is proven code-less, the hook comparison succeeds, or the account short circuit to.code.length == 0 || hook == sel accepts either case.