variable_of

Function variable_of 

fn variable_of(expr: &Expr<'_>) -> Option<VariableId>
The variable an expression is, behind the same conversions is_exactly_var sees through, or nothing when the expression is not a plain variable.