fn variable_of(expr: &Expr<'_>) -> Option<VariableId>Expand description
The variable an expression is, behind the same conversions is_exactly_var sees through,
or nothing when the expression is not a plain variable.
fn variable_of(expr: &Expr<'_>) -> Option<VariableId>The variable an expression is, behind the same conversions is_exactly_var sees through,
or nothing when the expression is not a plain variable.